@@ -1,6 +1,3 @@
-# -*- coding: UTF-8 -*-
-from __future__ import unicode_literals
-
 from django.contrib import admin
 
 from django_datawatch.models import Result, CheckExecution, ResultStatusHistory
