@@ -1,6 +1,3 @@
-# -*- coding: UTF-8 -*-
-from __future__ import unicode_literals
-
 from django_datawatch.backends.base import BaseBackend
 from django_datawatch.tasks import django_datawatch_enqueue, \
     django_datawatch_run, django_datawatch_refresh
