@@ -1,5 +1,3 @@
-# -*- coding: UTF-8 -*-
-from __future__ import unicode_literals
 import logging
 from contextlib import contextmanager
 
