@@ -1,6 +1,3 @@
-# -*- coding: UTF-8 -*-
-from __future__ import unicode_literals
-
 from celery import shared_task
 from celery.utils.log import get_task_logger
 
